---
name: Bug Report
about: Create a report to help us improve hyppo
label: bug

---

<!--
Thank you for taking the time to file a bug report.
Please fill in the fields below, deleting the sections that
don't apply to your issue. You can view the final output
by clicking the preview button above.
Note: This is a comment, and won't appear in the output.
-->

My issue is about ...

#### Reproducing code example:
<!--
If you place your code between the triple backticks below,
it will be rendered as a code block.
-->

```
Sample code to reproduce the problem
```

#### Error message
<!-- If any, paste the *full* error message inside a code block
as above (starting from line Traceback)
-->

```
Traceback (most recent call last):
  File "<stdin>", line 1, in <module>
  ...
```

#### Version information

- OS: [e.g. macOS]
- Python Version [e.g. 3.7.3]
- Package Version [e.g. 0.0.1]
